Example of patch based denoising methods
=======================================================

This folder contains example to denoise data on simulation data or raw data from scanner reconstruction. 
